#!/usr/bin/python3

# convert an rss feed to a gemini feed

# adapted from the atom to gemini feed script provided at:
# https://git.skyjake.fi/skyjake/lagrange/src/branch/dev/res/about/help.gmi#L404-L437

# Copyright 2020 Jaakko Keränen
#
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions are met:
#
# 1. Redistributions of source code must retain the above copyright notice,
# this list of conditions and the following disclaimer.
# 2. Redistributions in binary form must reproduce the above copyright notice,
# this list of conditions and the following disclaimer in the documentation
# and/or other materials provided with the distribution.
#
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
# AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
# IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
# ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE
# LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
# CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
# SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
# INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
# CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
# ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
# POSSIBILITY OF SUCH DAMAGE.

import sys
import xml.etree.ElementTree as ET
from datetime import datetime

root = ET.fromstring(sys.stdin.read())
if root.tag != 'rss':
    sys.exit(0)
feed_title = ''
feed_author = ''
feed_entries = []
for child in root:
    for subchild in child:
        if subchild.tag == 'title':
            feed_title = subchild.text
        elif subchild.tag == 'item':
            feed_entries.append(subchild)
print("20 text/gemini\r")
print(f'# {feed_title}')
for entry in feed_entries:
    entry_date = ''
    entry_title = ''
    entry_link = ''
    for child in entry:
        if child.tag == 'pubDate':
            entry_date = datetime.strptime(child.text, '%a, %d %b %Y %H:%M:%S %z').strftime('%Y-%m-%d')
        elif child.tag == 'title':
            entry_title = child.text
        elif child.tag == 'link':
            entry_link = child.text
    print(f'=> {entry_link} {entry_date} {entry_title}')
